Index: net/quic/quic_sent_packet_manager.h |
diff --git a/net/quic/quic_sent_packet_manager.h b/net/quic/quic_sent_packet_manager.h |
index ceda073eb0eb6abf7b78a37f79b3ade1e1c3ab54..f1ebe87e0fa417b69d997a0acd530e0c9b93c4d6 100644 |
--- a/net/quic/quic_sent_packet_manager.h |
+++ b/net/quic/quic_sent_packet_manager.h |
@@ -290,6 +290,10 @@ class NET_EXPORT_PRIVATE QuicSentPacketManager { |
// Retransmits all crypto stream packets. |
void RetransmitCryptoPackets(); |
+ // Retransmits two packets for an RTO and removes any non-retransmittable |
+ // packets from flight. |
+ void RetransmitRtoPackets(); |
+ |
// Retransmits all the packets and abandons by invoking a full RTO. |
void RetransmitAllPackets(); |
@@ -393,7 +397,7 @@ class NET_EXPORT_PRIVATE QuicSentPacketManager { |
size_t consecutive_tlp_count_; |
// Number of times the crypto handshake has been retransmitted. |
size_t consecutive_crypto_retransmission_count_; |
// Number of pending transmissions of TLP or crypto packets. |
size_t pending_timer_transmission_count_; |
// Maximum number of tail loss probes to send before firing an RTO. |
size_t max_tail_loss_probes_; |
@@ -393,7 +397,7 @@ class NET_EXPORT_PRIVATE QuicSentPacketManager { |
// Number of times the crypto handshake has been retransmitted. |
size_t consecutive_crypto_retransmission_count_; |
- // Number of pending transmissions of TLP or crypto packets. |
+ // Number of pending transmissions of TLP, RTO, or crypto packets. |
size_t pending_timer_transmission_count_; |
// Maximum number of tail loss probes to send before firing an RTO. |